==> eiffelstudio-18.01.10.1424.tar: F_code/C7/gb302.c <==
/*
 * Code for class GB_STANDARD_OBJECT_STONE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gb302.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GB_STANDARD_OBJECT_STONE}.make_with_object */
void F360_5415 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTCFDT;
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,loc1);
	RTLR(3,tr1);
	RTLR(4,tr2);
	RTLIU(5);
	
	RTEAA("make_with_object", 359, Current, 1, 1, 5257);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	tb1 = F2402_29098(RTCW(arg1));
	if (tb1) {
		RTHOOK(3);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_14_3_0_1_);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	}
	RTHOOK(4);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,2401,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9928(RTCW(tr1), ((EIF_INTEGER_32) 20L));
	loc1 = (EIF_REFERENCE) tr1;
	RTHOOK(5);
	F2402_29118(RTCW(arg1), loc1);
	RTHOOK(6);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(loc1)-562])(RTCW(loc1), arg1);
	RTHOOK(7);
	{
		static EIF_TYPE_INDEX typarr0[] = {1074,1295,1295,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F1075_9798(RTCW(tr1), ((EIF_INTEGER_32) 10L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTHOOK(8);
	F1081_9958(RTCW(loc1));
	for (;;) {
		RTHOOK(9);
		tb1 = F964_8514(RTCW(loc1));
		if (tb1) break;
		RTHOOK(10);
		tr1 = F1081_9932(RTCW(loc1));
		tb2 = F2402_29098(RTCW(tr1));
		if (tb2) {
			RTHOOK(11);
			tr1 = *(EIF_REFERENCE *)(Current);
			tr2 = F1081_9932(RTCW(loc1));
			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(tr2)+ _LNGOFF_14_3_0_1_);
			tr2 = F1081_9932(RTCW(loc1));
			ti4_2 = *(EIF_INTEGER_32 *)(RTCW(tr2)+ _LNGOFF_14_3_0_1_);
			F1075_9843(RTCW(tr1), ti4_1, ti4_2);
		}
		RTHOOK(12);
		F1081_9960(RTCW(loc1));
	}
	RTHOOK(13);
	RTLE;
	RTEE;
}

/* {GB_STANDARD_OBJECT_STONE}.object */
EIF_REFERENCE F360_5416 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("object", 359, Current, 0, 0, 5258);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_REFERENCE) *(EIF_REFERENCE *)(Current + _REFACS_1_);
}

/* {GB_STANDARD_OBJECT_STONE}.object_type */
EIF_REFERENCE F360_5417 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTEAA("object_type", 359, Current, 0, 0, 5259);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	Result = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_10_);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {GB_STANDARD_OBJECT_STONE}.internal_object */
EIF_REFERENCE F360_5418 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


void EIF_Minit302 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C7/gb302.c <==
/*
 * Code for class GB_COMPONENT_OBJECT_STONE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gb302.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GB_COMPONENT_OBJECT_STONE}.make_with_component */
void F360_5415 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("make_with_component", 359, Current, 0, 1, 5257);
	RTGC;
	RTHOOK(1);
	tr1 = arg1;
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = RTRV(eif_new_type(2399, 0), tr1);
	RTAR(Current, tr1);
	RTHOOK(2);
	{
		static EIF_TYPE_INDEX typarr0[] = {1074,1295,1295,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F1075_9801(RTCW(tr1), ((EIF_INTEGER_32) 10L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {GB_COMPONENT_OBJECT_STONE}.object */
EIF_REFERENCE F360_5416 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTEAA("object", 359, Current, 0, 0, 5258);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	Result = F2400_29101(RTCW(tr1));
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {GB_COMPONENT_OBJECT_STONE}.object_type */
EIF_REFERENCE F360_5417 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTEAA("object_type", 359, Current, 0, 0, 5259);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	Result = F2400_29102(RTCW(tr1));
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {GB_COMPONENT_OBJECT_STONE}.component */
EIF_REFERENCE F360_5418 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


void EIF_Minit302 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
